Implementations | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Implementations | AdminLTE v3 Documentaion

# Implementations

Thanks to many of AdminLTE users, there are multiple implementations of the template for easy integration with back-end frameworks. The following are some of them:

##### AdminLTE v3.0

- Laravel-AdminLTE v3.x by Jeroen Noten
- django-adminlte3 by d-demirci
- AdminLTE3.MVC by somaraj
- admin-lte-dotnet by iyilm4z
- WebPx.AdminLTE.AspNetCore by WebPx
- AdminLTE-3-Angular by erdkse
- AdminLTE-3-React by erdkse
- AdminLTE-3-Vue by erdkse

##### AdminLTE v2.4

- Laravel-AdminLTE v1.x & v2.x by Jeroen Noten
- adminlte-laravel by Sergi Tur Badenas
- yii2-adminlte-asset by Tobias Munk

##### AdminLTE v2.3

- AdminThemeBundle (Symfony) by Marc Bach
- lte-rails by Carlos at RacketLogger

##### AdminLTE v2.2

- AdminLTE-RTL by Mohammad Sharifi

##### AdminLTE v2.1

- adminlte2-rails by Nicolas Besnard

> ##### Note!

> These implementations are not supported by ColorlibHQ. However, they do provide a good example of how to integrate AdminLTE into different frameworks. For the latest release of AdminLTE, please visit our repository or website.